package cn.iocoder.yudao.module.inspection.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import cn.iocoder.yudao.module.inspection.entity.InspectionFile;

/**
 * inspectionFileService接口
 *
 * @author zcy
 * @date 2023-10-13
 */
public interface IInspectionFileService  extends IService<InspectionFile>
{
    /**
     * 查询inspectionFile
     *
     * @param id inspectionFile主键
     * @return inspectionFile
     */
    public InspectionFile selectInspectionFileById(Long id);

    /**
     * 查询inspectionFile列表
     *
     * @param inspectionFile inspectionFile
     * @return inspectionFile集合
     */
    public List<InspectionFile> selectInspectionFileList(InspectionFile inspectionFile);

    /**
     * 新增inspectionFile
     *
     * @param inspectionFile inspectionFile
     * @return 结果
     */
    public int insertInspectionFile(InspectionFile inspectionFile);

    /**
     * 修改inspectionFile
     *
     * @param inspectionFile inspectionFile
     * @return 结果
     */
    public int updateInspectionFile(InspectionFile inspectionFile);

    /**
     * 批量删除inspectionFile
     *
     * @param ids 需要删除的inspectionFile主键集合
     * @return 结果
     */
    public int deleteInspectionFileByIds(Long[] ids);

    /**
     * 删除inspectionFile信息
     *
     * @param id inspectionFile主键
     * @return 结果
     */
    public int deleteInspectionFileById(Long id);
}
